package com.ruoyi.ibs.dashboard.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.ibs.dashboard.domain.LscjSysuser;

import java.util.List;


/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author ruoyi
 * @date 2025-08-04
 */
public interface LscjSysuserMapper  extends BaseMapper<LscjSysuser>
{
    /**
     * 查询【请填写功能名称】
     *
     * @param orgId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public LscjSysuser selectLscjSysuserByOrgId(String orgId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param lscjSysuser 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<LscjSysuser> selectLscjSysuserList(LscjSysuser lscjSysuser);


    public int selectLscjSysuserListCount(LscjSysuser lscjSysuser);
    /**
     * 新增【请填写功能名称】
     *
     * @param lscjSysuser 【请填写功能名称】
     * @return 结果
     */
    public int insertLscjSysuser(LscjSysuser lscjSysuser);

    /**
     * 修改【请填写功能名称】
     *
     * @param lscjSysuser 【请填写功能名称】
     * @return 结果
     */
    public int updateLscjSysuser(LscjSysuser lscjSysuser);



    /**
     * 批量删除【请填写功能名称】
     *
     * @param orgIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLscjSysuserByIds(String[] ids);
}
